@@ -108,14 +108,14 @@ impl Platform for PlatformImpl {
         sysctl!(V_CACHE_COUNT, &mut cache, mem::size_of::<usize>(), false);
         let mut free: usize = 0;
         sysctl!(V_FREE_COUNT, &mut free, mem::size_of::<usize>());
-        let arc = ByteSize::b(zfs_arc_size().unwrap_or(0));
+        let arc = readable_byte::b(zfs_arc_size().unwrap_or(0));
         let pmem = PlatformMemory {
-            active: ByteSize::kib((active as u64) << *bsd::PAGESHIFT),
-            inactive: ByteSize::kib((inactive as u64) << *bsd::PAGESHIFT),
-            wired: saturating_sub_bytes(ByteSize::kib((wired as u64) << *bsd::PAGESHIFT), arc),
-            cache: ByteSize::kib((cache as u64) << *bsd::PAGESHIFT),
+            active: readable_byte::kib((active as u64) << *bsd::PAGESHIFT),
+            inactive: readable_byte::kib((inactive as u64) << *bsd::PAGESHIFT),
+            wired: saturating_sub_bytes(readable_byte::kib((wired as u64) << *bsd::PAGESHIFT), arc),
+            cache: readable_byte::kib((cache as u64) << *bsd::PAGESHIFT),
             zfs_arc: arc,
-            free: ByteSize::kib((free as u64) << *bsd::PAGESHIFT),
+            free: readable_byte::kib((free as u64) << *bsd::PAGESHIFT),
         };
         Ok(Memory {
             total: pmem.active + pmem.inactive + pmem.wired + pmem.cache + arc + pmem.free,
@@ -214,9 +214,9 @@ fn statfs_to_fs(fs: &statfs) -> Filesystem {
         files: (fs.f_files as usize).saturating_sub(fs.f_ffree as usize),
         files_total: fs.f_files as usize,
         files_avail: fs.f_ffree as usize,
-        free: ByteSize::b(fs.f_bfree * fs.f_bsize),
-        avail: ByteSize::b(fs.f_bavail as u64 * fs.f_bsize),
-        total: ByteSize::b(fs.f_blocks * fs.f_bsize),
+        free: readable_byte::b(fs.f_bfree * fs.f_bsize),
+        avail: readable_byte::b(fs.f_bavail as u64 * fs.f_bsize),
+        total: readable_byte::b(fs.f_blocks * fs.f_bsize),
         name_max: fs.f_namemax as usize,
         fs_type: unsafe {
             ffi::CStr::from_ptr(&fs.f_fstypename[0])
